/**
 * Copyright 2013 Parallel Data Lab (Carnegie Mellon University)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file ediversion.c
 *
 * @brief Implements the Emulator Versioning subsystem.
 *
 * TODO Come up with a better design for registering new versions.
 *
 * @author Anand Suresh <anandsuresh@cmu.edu>
 */

#include <stdlib.h>
#include <string.h>

#include "debug.h"
#include "ediversion.h"




/* -- External References -- */
extern edi_vops_t* ediv0_init();



/* -- Function Implementations -- */

/**
 * @brief Initializes the Emulator Versioning Module.
 *
 * This function initializes the data structures required by the Emulator
 * Versioning Module and then calls the initialization functions for each of the
 * registered versions.
 *
 * @return 0 on success; -1 on failure registering any version
 */
int ediv_init() {
    int retval = 0;


    /* Initialize the data structures */
    memset(&edi_versions, 0, sizeof(edi_vops_t*) * (MAX_EDI_VERSION + 1));


    /* Initialize each version supported by the Emulator Versioning module */
    /* =================================================================== */

    /* Version 0 */
    if ((edi_versions[0] = ediv0_init()) == NULL) {
        dbg("Version 0 initialization failed!\n");
        retval = -1;
    }


    /* TODO Add initialization for future versions here */

    return retval;
}



/**
 * @brief Returns if the specified version is valid
 *
 * @param version The version number to be verified
 *
 * @return 1 on success; 0 on failure
 */
int ediv_is_valid(uint32_t version) {
    /* Ensure that the version is less than the Max version supported */
    return (version <= MAX_EDI_VERSION);
}
