/**
 * Copyright 2013 Parallel Data Lab (Carnegie Mellon University)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file emulator.h
 *
 * @brief Defines the Macros, data types and function prototypes for using the
 * SMR Emulator.
 *
 * @author Anand Suresh <anandsuresh@cmu.edu>
 *
 * @bug No known bugs
 */

#ifndef __EMULATOR_H_
#define __EMULATOR_H_

#ifdef __cplusplus
extern "C" {
#endif

#include "emutypes.h"
#include "emuerror.h"

/*#ifdef _EDI_ON_RAW
#define _EDI_ON_RAW 1
#else
#define _EDI_ON_RAW 0
#endif*/

/* -- Macro Definitions -- */

/**
 * @brief Maximum number of simultaneous EDIs that can be opened.
 */
#define MAX_EDIS 8		// Maximum no. of EDIs that can be opened simultaneously



/* -- Function Prototypes -- */

int edi_init();
#ifdef _EDI_ON_RAW
int edi_open(const char*, const char  *, int *);
int edi_close(int, int);
#else
int edi_open(const char  *);
int edi_close(int);
#endif

int edi_modesense(int, inq_t, void*);
int edi_managebands(int, svc_act_t, band_t*, rba_t*, int);
#ifdef _EDI_ON_RAW
int edi_read(int, int, band_t, rba_t, char*, rba_t);
int edi_write(int, int, band_t, rba_t, char*, rba_t);
#else
int edi_read(int, band_t, rba_t, char*, rba_t);
int edi_write(int, band_t, rba_t, char*, rba_t);
#endif


#ifdef __cplusplus
}
#endif
#endif  /* __EMULATOR_H_ */
