/**
 * Copyright 2013 Parallel Data Lab (Carnegie Mellon University)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file emudiskimg.h
 *
 * @brief Defines the Macros, data types and function prototypes pertaining to
 * the Emulated Disk Image file.
 *
 * @author Anand Suresh <anandsuresh@cmu.edu>
 */

#ifndef __EMUDISKIMG_H_
#define __EMUDISKIMG_H_

#include <stdint.h>



/* -- Macro Definitions -- */

/**
 * @brief Defines the file offset at which the EDI Header should start.
 */
#define OFF_HEADER	sizeof(edi_ident_t)



/* -- Type Definitions -- */

/**
 * @brief Defines the structure of the header file for a disk image.
 *
 * @param magic_no The Magic Number that identifies an SMR Emulated Disk Image
 * @param version The version of the disk image file format
 */
typedef struct {
    uint32_t magic_no;
    uint32_t version;
} edi_ident_t;



/* -- Function Prototypes -- */
#ifdef _EDI_ON_RAW
int edi_create(const char*, const char*, uint32_t, ...);
#else
int edi_create(const char *, uint32_t, ...);
#endif
int edi_dump(int);



#endif      /* __EMUDISKIMG_H_ */
