/**
 * Copyright 2013 Parallel Data Lab (Carnegie Mellon University)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file band_bitmap.h
 *
 * @brief Defines function prototypes pertaining to Bands
 *
 * @author Jainam Shah <jashah@andrew.cmu.edu>
 */

#ifndef __BAND_BITMAP_H_
#define __BAND_BITMAP_H_

#include <limits.h>

#include "emutypes.h"



/* ====================== */
/* -- Type Definitions -- */
/* ====================== */

/**
 * @brief Defines the structure of an Open Band, used to denote the band that
 * was written to last
 */
typedef struct {
    band_t band;
    rba_t  rba;
    rba_t  total_blocks;
}open_band_t;



/* ====================== */
/* -- Global Variables -- */
/* ====================== */

extern open_band_t open_band;



/* ========================= */
/* -- Function Prototypes -- */
/* ========================= */

int init_band_bitmap(void);
int get_freebandnum();
void put_freebandnum(int band_num);
int test_bandusage(int band_num);
//int get_writebandnum(int size);
void put_setbandnum(int band_num);
int get_openband(int edi_fd, open_band_t *band, int block_count);



#endif /* __BAND_BITMAP_H_ */
