#!/bin/bash
#
# Copyright 2013 Parallel Data Lab (Carnegie Mellon University)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# configurables and defaults
AGEDISK="./agedisk"
SMR="/tmp/smr"
FILE="/filestats.txt"
opcount=100000
fillupsize=268435456
debug=0
deletefile="delete.txt"
createfile="create.txt"
export TIME="\n#User %U s, System %S s, Real %E \n#file system Input/output from process %I/%O"

# configurables and defaults end

function usage()
{
    echo "Usage :$0" 
    echo "      -h   :print this help"
    echo "      -n n :operation count n"
    echo "      -f <filename> :delete file"
    echo "      -c <filename> :create file"
    echo "      -d   :debug agedisk"
}

#
# main
#

while getopts "mn:df:c:" opt
do
    case $opt in
        n) opcount=$OPTARG ;;
        m) SMR="/tmp/smr" ;;   
        d) debug=1 ;;
        f) deletefile=$OPTARG ;;
        c) createfile=$OPTARG ;;
        h) usage; exit 1 ;;
        ?) usage; exit 1 ;;
    esac
done

if [ $debug -eq 1 ]; then
    echo "debug agedisk"
    echo "delete file : $deletefile"
    echo "create file : $createfile"
    echo "stats file : $STATSPATH$FILE"
#    gdb -ex run --eval-command=quit --arg $AGEDISK -s 268435456 -n $opcount -d $deletefile -c $createfile -o $SMR/sfs/.aged_new_files -f $STATSPATH$FILE
    gdb --arg $AGEDISK -s $fillupsize -n $opcount -d $deletefile -c $createfile -o $SMR/sfs/.aged_new_files -f $STATSPATH$FILE
else 
   echo " start filling up disk in $SMR/sfs/"
   /usr/bin/time -o $STATSPATH$FILE -a $AGEDISK -s $fillupsize -n $opcount -d $deletefile -c $createfile -o $SMR/sfs/.aged_new_files -f $STATSPATH$FILE
#> /dev/null 2>&1
fi
