/**
 * Copyright 2013 Parallel Data Lab (Carnegie Mellon University)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
  * @file aging.h
  *
  * @brief Defines types and function prototypes pertaining to Disk Aging
  *
  * @author Praveen Kumar Ramakrishnan <praveenr@andrew.cmu.edu>
  */

#ifndef __AGING_H_
#define __AGING_H_

#include "variable_queue.h"

#define NUM_CREATE 4
#define NUM_DELETE 1

#define CREATE_DATA_FILE "create.txt"
#define DELETE_DATA_FILE "delete.txt"

#define MAXLINE 80
#define OUTPUT_DIR ".aged_files"

#define RANDOM_SEED 1234

#define INCREASE_AGE_OP_COUNT 10

typedef struct file_data_s {
    int id;
    int blocksize;
    int blockcount;
    Q_NEW_LINK(file_data_s) link;
} file_data_t;

Q_NEW_HEAD(file_data_queue_t, file_data_s);

typedef struct {
    int weight;

    /* For create operation */
    int blocksize;
    int blockcount;

    /* For delete operation */
    file_data_queue_t file_list;

    /* For collecting stats */
    int actualcount;
} randomizer_member_t;

typedef struct {
    int count;
    int total_weight;
    randomizer_member_t *members;
} randomizer_t;

#endif
