#!/bin/bash

# Ensure that the script has been passed the required no. of arguments
MAKE_TARGET="all"
if [ $# -gt 0 ]; then
    if [ $1 == "log" ]; then
        MAKE_TARGET="log"
    elif [ $1 == "debug" ]; then
        MAKE_TARGET="debug"
    fi
fi


# Define the variables
PATH_SRC="../../fuse"
PATH_BASE="/tmp/smr"
PATH_SMR=$PATH_BASE"/sfs"
PATH_TRN=$PATH_BASE"/trn"
PATH_USHNG=$PATH_BASE"/unshingled"
PATH_TRNBK=$PATH_BASE"/trnbk"
PATH_TMPFS=$PATH_BASE"/tmpfs"
PATH_SHIMG=$PATH_BASE"/edi.img"


# Specify the working environment
echo "Base directory:                      " $PATH_BASE
echo "Transparent FUSE directory:          " $PATH_TRN
echo "Transparent FUSE backing directory : " $PATH_TRNBK
echo "SMR directory:                       " $PATH_SMR
echo "Unshingled directory:                " $PATH_USHNG
echo "Shingled Image File:                 " $PATH_SHIMG
echo "tmpFS directory:                     " $PATH_TMPFS
echo "Target:                              " $MAKE_TARGET
echo


# Clean up the working environment
echo "Cleaning up..."
fusermount -u $PATH_SMR
fusermount -u $PATH_TRN
sudo umount $PATH_TMPFS
#rm -rf $PATH_BASE/*
rm /tmp/smr*.csv
rm /tmp/smr*.log
echo


# Make the executables
echo "Generating executables..."
make clean --directory=$PATH_SRC
make $MAKE_TARGET --directory=$PATH_SRC
if [ $? -ne 0 ]; then
    echo "Error running test!"
    exit -1
fi
echo


# Setup the environment
echo "Setting up the environment..."

mkdir $PATH_BASE
mkdir $PATH_TRN
mkdir $PATH_TRNBK
mkdir $PATH_SMR
mkdir $PATH_USHNG
mkdir $PATH_TMPFS
mkdir $PATH_BASE/temp

sudo mount -t tmpfs -o size=2G tmpfs $PATH_TMPFS

rm -f *.img
../../emulator/edicreate -v 0 -s 4096 -c 33 -b 4096 -f $PATH_SHIMG

echo


# Launch the FUSE process
if [ $MAKE_TARGET == "debug" ]; then
    gdb --args $PATH_SRC/shingledfs $PATH_USHNG $PATH_TMPFS $PATH_SHIMG $PATH_SMR -o big_writes -s
else
    $PATH_SRC/shingledfs $PATH_USHNG $PATH_TMPFS $PATH_SHIMG $PATH_SMR -o big_writes -s
fi

$PATH_SRC/transparency $PATH_TRNBK $PATH_TRN -o big_writes -s

ps -e | grep shingledfs
ps -e | grep transparency

